#![no_std]
#![no_main]
#![feature(allocator_api)]
#![allow(unused_imports)]

use gila::arch::current::display;
use gila::arch::current::*;
use gila::boot::*;
use gila::log::*;
use gila::memory;
use gila::memory::alloc::*;
use gila::panic;
use gila::params;
use gila::params::get_kernel_params;
use gila::process;

#[unsafe(no_mangle)]
unsafe extern "C" fn main() -> ! {
    assert!(BASE_REVISION.is_supported());

    let kernel_file_response = FILE_REQUEST.get_response().unwrap();

    let kernel_parameters = get_kernel_params(kernel_file_response.file().cmdline());

    if let Some(level) = kernel_parameters.get("-loglevel") {
        if let Ok(parsed_level) = LogLevel::try_from(level.as_str()) {
            LOGGER.lock().level = parsed_level;
        }
    }
    if let Some(device) = kernel_parameters.get("-logdev") {
        let log_device_list: vec::Vec<&str> = device.split(',').collect();
        if log_device_list.contains(&"display") {
            // Append display console to log subs
        }
        if log_device_list.contains(&"serial") {
            // Append serial console to log subs
        }
    }

    let _smp_response = SMP_REQUEST.get_response();

    loop {
        unsafe {
            asm::halt();
        }
    }
}
